// Author: Patrick Stickler <patrick.stickler@nokia.com>
// Copyright (C) 2002 Nokia. All rights reserved.
// Usage is governed by the license terms defined in the file
// NOKIA_LICENSE which was distributed with this file.

package UAProf;

import Datatypes.*;
import java.util.regex.*;

public class Dimension extends XSD.AnySimpleType
{
   private static final Pattern pattern = Pattern.compile ("\\A[0-9]+x[0-9]+\\Z");
   
   public Dimension ()
   {
   }
   
   public Dimension (java.lang.String lform)
   throws InvalidLexicalForm
   {
      this.setValue (lform);
   }
   
   private class NumberPair
   {
      int x;
      int y;
      
      NumberPair (java.lang.String lform)
      throws NumberFormatException
      {
         java.lang.String lformX = null;
         java.lang.String lformY = null;
         
         java.util.StringTokenizer tokenizer = new java.util.StringTokenizer (lform, "x");
         
         x = java.lang.Integer.parseInt (tokenizer.nextToken());
         y = java.lang.Integer.parseInt (tokenizer.nextToken());
      }
      
      public int compareTo (NumberPair value)
      {
         if (this.x == value.x && this.y == value.y)  return  0;
         if (this.x <= value.x && this.y <= value.y)  return -1;
         return 1;
      }
      
      public boolean equals (NumberPair value)
      {
         if (compareTo (value) == 0)
            return true;
         else
            return false;
      }
      
      public java.lang.String toString ()
      {
         return new java.lang.String (x + "x" + y);
      }
   }
   
   /** Returns 0 if both x and y dimensions are equal to those of value.
    *  Returns a value less than zero if both x and y dimensions are less than those of value.
    *  Returns a value greater than zero if either x or y dimensions are greater than those of value.
    */
   
   public final int compareTo (Datatype value)
   throws InvalidComparison
   {
      final Class roottype = new Dimension ().getClass ();
      
      Class datatypeX = this.getClass ();
      Class datatypeY = value.getClass ();
      
      if (! roottype.isInstance (value))
         throw new InvalidComparison (datatypeX.getName () + " " + datatypeY.getName ());
      
      Dimension valueX = (Dimension) this;
      Dimension valueY = (Dimension) value;
      NumberPair nativeValueX = valueX.getNativeValue ();
      NumberPair nativeValueY = valueY.getNativeValue ();
      return nativeValueX.compareTo (nativeValueY);
   }
   
   public final boolean equals (Datatype value)
   throws InvalidComparison
   {
      if (this.compareTo (value) == 0)
         return true;
      else
         return false;
   }
   
   public java.lang.String lexicalForm ()
   {
      return nativeValue.toString ();
   }
   
   public void setValue (java.lang.String lform)
   throws InvalidLexicalForm
   {
      if (! this.isValidForm (lform)) throw new InvalidLexicalForm (lform);
      nativeValue = new NumberPair (lform);
   }
   
   public boolean isValidForm (java.lang.String lform)
   {
      Matcher matcher = pattern.matcher (lform);
      return matcher.matches ();
   }
   
   protected final NumberPair getNativeValue ()
   {
      return (NumberPair) nativeValue;
   }
}
