// Author: Patrick Stickler <patrick.stickler@nokia.com>
// Copyright (C) 2002 Nokia. All rights reserved.
// Usage is governed by the license terms defined in the file
// NOKIA_LICENSE which was distributed with this file.

package XSD;

import Datatypes.*;
import java.util.regex.*;

public class Boolean extends AnySimpleType
{
   private static final Pattern pattern = Pattern.compile ("\\A(true)|(false)|[01]\\Z");
   
   public Boolean ()
   {
   }
   
   public Boolean (java.lang.String lform)
   throws InvalidLexicalForm
   {
      this.setValue (lform);
   }
   
   public final boolean equals (Datatype value)
   throws InvalidComparison
   {
      final Class roottype = new Boolean ().getClass ();
      
      Class datatypeX = this.getClass ();
      Class datatypeY = value.getClass ();
      
      if (! roottype.isInstance (value))
         throw new InvalidComparison (datatypeX.getName () + " " + datatypeY.getName ());
      
      Boolean valueX = (Boolean) this;
      Boolean valueY = (Boolean) value;
      java.lang.Integer nativeValueX = (java.lang.Integer) valueX.getNativeValue ();
      java.lang.Integer nativeValueY = (java.lang.Integer) valueY.getNativeValue ();
      
      int result = nativeValueX.compareTo (nativeValueY);
      if (result == 0)
         return true;
      else
         return false;
   }
   
   public java.lang.String lexicalForm ()
   {
      final java.lang.Integer yes = new java.lang.Integer (1);
      
      if (nativeValue.equals (yes))
         return "true";
      else
         return "false";
   }
   
   public void setValue (java.lang.String lform)
   throws InvalidLexicalForm
   {
      if (! this.isValidForm (lform)) throw new InvalidLexicalForm (lform);
      
      if (lform.equals ("true"))
         nativeValue = new java.lang.Integer (1);
      else if (lform.equals ("false"))
         nativeValue = new java.lang.Integer (0);
      else
         nativeValue = new java.lang.Integer (lform);
   }
   
   public boolean isValidForm (java.lang.String lform)
   {
      Matcher matcher = pattern.matcher (lform);
      return matcher.matches ();
   }
   
   protected final java.lang.Integer getNativeValue ()
   {
      return (java.lang.Integer) nativeValue;
   }
}
