// Author: Patrick Stickler <patrick.stickler@nokia.com>
// Copyright (C) 2002 Nokia. All rights reserved.
// Usage is governed by the license terms defined in the file
// NOKIA_LICENSE which was distributed with this file.

package XSD;

import Datatypes.*;
import java.util.regex.*;
import java.util.*;
import org.w3c.util.*;

public class DateTime extends AnySimpleType
{
   private static final Pattern pattern  = Pattern.compile ("\\A-?[0-9]{4,}-[0-9]{2}-[0-9]{2}T(([01][0-9])|(2[0-3])):[0-5][0-9]:[0-5][0-9](Z|([-\\+](([01][0-9])|(2[0-3])):[0-5][0-9]))?\\Z");
   private static final Pattern xpattern = Pattern.compile ("\\A0000-.*\\Z");
   
   public DateTime ()
   {
   }
   
   public DateTime (java.lang.String lform)
   throws InvalidLexicalForm
   {
      this.setValue (lform);
   }
   
   public final int compareTo (Datatype value)
   throws InvalidComparison
   {
      final Class roottype = new DateTime ().getClass ();
      
      Class datatypeX = this.getClass ();
      Class datatypeY = value.getClass ();
      
      if (! roottype.isInstance (value))
         throw new InvalidComparison (datatypeX.getName () + " " + datatypeY.getName ());
      
      DateTime valueX = (DateTime) this;
      DateTime valueY = (DateTime) value;
      java.util.Date nativeValueX = (java.util.Date) valueX.getNativeValue ();
      java.util.Date nativeValueY = (java.util.Date) valueY.getNativeValue ();
      
      return nativeValueX.compareTo (nativeValueY);
   }
   
   public final boolean equals (Datatype value)
   throws InvalidComparison
   {
      if (compareTo (value) == 0)
         return true;
      else
         return false;
   }
   
   public java.lang.String lexicalForm ()
   {
      return org.w3c.util.DateParser.getIsoDate((java.util.Date) nativeValue);
   }
   
   public void setValue (java.lang.String lform)
   throws InvalidLexicalForm
   {
      if (! this.isValidForm (lform)) throw new InvalidLexicalForm (lform);
      
      try
      {
         nativeValue = org.w3c.util.DateParser.parse (lform);
      }
      catch (Exception e)
      {
         throw new InvalidLexicalForm (lform);
      }
   }
   
   public boolean isValidForm (java.lang.String lform)
   {
      Matcher matcher = pattern.matcher (lform);
      if (! matcher.matches ()) return false;
      
      matcher = xpattern.matcher (lform);
      if (matcher.matches ()) return false;
      
      return true;
   }
   
   protected final java.util.Date getNativeValue ()
   {
      return (java.util.Date) nativeValue;
   }
}
