// Author: Patrick Stickler <patrick.stickler@nokia.com>
// Copyright (C) 2002 Nokia. All rights reserved.
// Usage is governed by the license terms defined in the file
// NOKIA_LICENSE which was distributed with this file.

package XSD;

import java.util.regex.*;
import Datatypes.*;

public class Decimal extends AnySimpleType
{   
   private static final Pattern pattern = Pattern.compile ("\\A[-\\+]?[0-9]+(\\.[0-9]+)?\\Z");
   
   public Decimal ()
   {
   }
   
   public Decimal (java.lang.String lform)
   throws InvalidLexicalForm
   {
      this.setValue (lform);
   }
   
   public final int compareTo (Datatype value)
   throws InvalidComparison
   {
      // XSD.Decimal is the common "root" superclass by which all subtypes are compared.
      // Any decendants of XSD.Decimal may be safely compared, even if one is not the
      // decendant of the other. It is sufficient that they share the same root ancestor.
      
      final Class roottype = new Decimal ().getClass ();
      
      Class datatypeX = this.getClass ();
      Class datatypeY = value.getClass ();
      
      if (! roottype.isInstance (value))
         throw new InvalidComparison (datatypeX.getName () + " " + datatypeY.getName ());
      
      Decimal valueX = (Decimal) this;
      Decimal valueY = (Decimal) value;
      java.lang.Double nativeValueX = valueX.getNativeValue ();
      java.lang.Double nativeValueY = valueY.getNativeValue ();
      return nativeValueX.compareTo (nativeValueY);
   }
   
   public final boolean equals (Datatype value)
   throws InvalidComparison
   {
      if (this.compareTo (value) == 0)
         return true;
      else
         return false;
   }
   
   public java.lang.String lexicalForm ()
   {
      return nativeValue.toString ();
   }
   
   public void setValue (java.lang.String lform)
   throws InvalidLexicalForm
   {
      if (! this.isValidForm (lform)) throw new InvalidLexicalForm (lform);
      nativeValue = new java.lang.Double (lform);
   }
   
   public boolean isValidForm (java.lang.String lform)
   {
      Matcher matcher = pattern.matcher (lform);
      return matcher.matches ();
   }
   
   protected final java.lang.Double getNativeValue ()
   {
      return (java.lang.Double) nativeValue;
   }
}
