// Author: Patrick Stickler <patrick.stickler@nokia.com>
// Copyright (C) 2002 Nokia. All rights reserved.
// Usage is governed by the license terms defined in the file
// NOKIA_LICENSE which was distributed with this file.

package XSD;

import Datatypes.*;

public class String extends AnySimpleType
{
   public String ()
   {
   }
   
   public String (java.lang.String lform)
   throws InvalidLexicalForm
   {
      this.setValue (lform);
   }
   
   public final int compareTo (Datatype value)
   throws InvalidComparison
   {
      // XSD.String is the common "root" superclass by which all subtypes are compared.
      // Any decendants of XSD.String may be safely compared, even if one is not the
      // decendant of the other. It is sufficient that they share the same root ancestor.
      
      final Class roottype = new String ().getClass ();
      
      Class datatypeX = this.getClass ();
      Class datatypeY = value.getClass ();
      
      if (! roottype.isInstance (value))
         throw new InvalidComparison (datatypeX.getName () + " " + datatypeY.getName ());
      
      String valueX = (String) this;
      String valueY = (String) value;
      java.lang.String nativeValueX = (java.lang.String) valueX.getNativeValue ();
      java.lang.String nativeValueY = (java.lang.String) valueY.getNativeValue ();
      
      return nativeValueX.compareTo (nativeValueY);
   }
   
   public final boolean equals (Datatype value)
   throws InvalidComparison
   {
      if (this.compareTo (value) == 0)
         return true;
      else
         return false;
   }
   
   public java.lang.String lexicalForm ()
   {
      return new java.lang.String ((java.lang.String) nativeValue);
   }
   
   public void setValue (java.lang.String lform)
   throws InvalidLexicalForm
   {
      if (! this.isValidForm (lform)) throw new InvalidLexicalForm (lform);
      nativeValue = new java.lang.String (lform);
   }
   
   public boolean isValidForm (java.lang.String lform)
   {
      return true;
   }
   
   protected final java.lang.String getNativeValue ()
   {
      return lexicalForm ();
   }
}
